@@ -1,6 +1,6 @@
 import click
 import os
-from . import cli, pass_config, Commands
+from .cli import cli, pass_config, Commands
 from .lib_clickhelpers import AliasedGroup
 from .tools import execute_script
 import subprocess
@@ -40,7 +40,7 @@ def dev(ctx, config, build, kill):
 def ps(config):
     if config.use_docker:
         from .lib_control_with_docker import ps as lib_ps
-    return lib_ps()
+    return lib_ps(config)
 
 
 @docker.command(name="exec")
@@ -50,7 +50,7 @@ def ps(config):
 def execute(config, machine, args):
     if config.use_docker:
         from .lib_control_with_docker import execute as lib_execute
-    lib_execute(machine, args)
+    lib_execute(config, machine, args)
 
 
 @docker.command(name="kill")
@@ -110,10 +110,8 @@ def recreate(ctx, config, machines):
 @click.pass_context
 def up(ctx, config, machines, daemon):
     from .lib_setup import _status
-    if config.use_docker:
-        from .lib_control_with_docker import up as lib_up
-    else:
-        from .lib_control_native import up as lib_up
+    from .lib_control_with_docker import up as lib_up
+
     lib_up(ctx, config, machines, daemon, remove_orphans=True)
     execute_script(
         config, config.files["after_up_script"], "Possible after up script here:"
@@ -130,8 +128,7 @@ def up(ctx, config, machines, daemon):
 @pass_config
 @click.pass_context
 def down(ctx, config, machines, volumes, remove_orphans, postgres_volume):
-    if config.use_docker:
-        from .lib_control_with_docker import down as lib_down
+    from .lib_control_with_docker import down as lib_down
     from .lib_db_snapshots_docker_zfs import NotZFS
 
     if postgres_volume or volumes:
@@ -152,8 +149,8 @@ def down(ctx, config, machines, volumes, remove_orphans, postgres_volume):
 @pass_config
 @click.pass_context
 def stop(ctx, config, machines):
-    if config.use_docker:
-        from .lib_control_with_docker import stop as lib_stop
+    from .lib_control_with_docker import stop as lib_stop
+
     lib_stop(ctx, config, machines)
 
 
@@ -162,8 +159,8 @@ def stop(ctx, config, machines):
 @pass_config
 @click.pass_context
 def rebuild(ctx, config, machines):
-    if config.use_docker:
-        from .lib_control_with_docker import rebuild as lib_rebuild
+    from .lib_control_with_docker import rebuild as lib_rebuild
+
     lib_rebuild(ctx, config, machines)
 
 
@@ -172,8 +169,8 @@ def rebuild(ctx, config, machines):
 @pass_config
 @click.pass_context
 def restart(ctx, config, machines):
-    if config.use_docker:
-        from .lib_control_with_docker import restart as lib_restart
+    from .lib_control_with_docker import restart as lib_restart
+
     lib_restart(ctx, config, machines)
 
 
@@ -182,8 +179,8 @@ def restart(ctx, config, machines):
 @pass_config
 @click.pass_context
 def rm(ctx, config, machines):
-    if config.use_docker:
-        from .lib_control_with_docker import rm as lib_rm
+    from .lib_control_with_docker import rm as lib_rm
+
     lib_rm(ctx, config, machines)
 
 
@@ -192,8 +189,8 @@ def rm(ctx, config, machines):
 @pass_config
 @click.pass_context
 def attach(ctx, config, machine):
-    if config.use_docker:
-        from .lib_control_with_docker import attach as lib_attach
+    from .lib_control_with_docker import attach as lib_attach
+
     lib_attach(ctx, config, machine)
 
 
@@ -208,8 +205,8 @@ def attach(ctx, config, machine):
 def build(ctx, config, machines, pull, no_cache, push, plain):
     if plain:
         os.environ["BUILDKIT_PROGRESS"] = "plain"
-    if config.use_docker:
-        from .lib_control_with_docker import build as lib_build
+    from .lib_control_with_docker import build as lib_build
+
     lib_build(ctx, config, machines, pull, no_cache, push)
 
 
@@ -220,8 +217,8 @@ def build(ctx, config, machines, pull, no_cache, push, plain):
 @pass_config
 @click.pass_context
 def debug(ctx, config, machine, ports, command):
-    if config.use_docker:
-        from .lib_control_with_docker import debug as lib_debug
+    from .lib_control_with_docker import debug as lib_debug
+
     lib_debug(ctx, config, machine, ports, cmd=command)
 
 
@@ -231,8 +228,8 @@ def debug(ctx, config, machine, ports, command):
 @pass_config
 @click.pass_context
 def run(ctx, config, machine, args, **kwparams):
-    if config.use_docker:
-        from .lib_control_with_docker import run as lib_run
+    from .lib_control_with_docker import run as lib_run
+
     lib_run(ctx, config, machine, args, **kwparams)
 
 
@@ -242,8 +239,8 @@ def run(ctx, config, machine, args, **kwparams):
 @pass_config
 @click.pass_context
 def runbash(ctx, config, machine, args, **kwparams):
-    if config.use_docker:
-        from .lib_control_with_docker import runbash as lib_runbash
+    from .lib_control_with_docker import runbash as lib_runbash
+
     lib_runbash(ctx, config, machine, args, **kwparams)
 
 
@@ -253,9 +250,9 @@ def runbash(ctx, config, machine, args, **kwparams):
 @click.option("-f", "--follow", is_flag=True)
 @pass_config
 def logall(config, machines, follow, lines):
-    if config.use_docker:
-        from .lib_control_with_docker import logall as lib_logall
-    lib_logall(machines, follow, lines)
+    from .lib_control_with_docker import logall as lib_logall
+
+    lib_logall(config, machines, follow, lines)
 
 
 @docker.command()
@@ -269,9 +266,9 @@ def logall(config, machines, follow, lines):
 @pass_config
 def shell(config, command, queuejobs):
     command = "\n".join(command)
-    if config.use_docker:
-        from .lib_control_with_docker import shell as lib_shell
-    lib_shell(command, queuejobs)
+    from .lib_control_with_docker import shell as lib_shell
+
+    lib_shell(config, command, queuejobs)
 
 
 # problem with stdin: debug then display missing
